@@ -12,8 +12,9 @@ import requests
 
 from .mongo_tools import clean_json
 from .data_utils import to_dicts
+from .parsing import parse_float, parse_int
 
-__version__ = "0.1.20"
+__version__ = "0.1.21"
 
 
 def logged_user(logger=logger):
@@ -33,21 +34,6 @@ def logged_user(logger=logger):
     return logging_user_wrapper
 
 
-def parse_float(value: str) -> float:
-    value = value.strip()
-    if value == "-":
-        return 0.0
-
-    return float(value.replace(",", "").replace("$", ""))
-
-
-def parse_int(value: str):
-    float_value = parse_float(value)
-    if not float_value.is_integer():
-        raise ValueError(f"{value} is not an integer")
-    return int(float_value)
-
-
 def now_utc():
     return datetime.now(pytz.utc).replace(second=0, microsecond=0, tzinfo=None)
 
